@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2010 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: DemoTitle.cpp,v 1.14 2009/02/09 09:04:45 bowkenken Exp $
+* $Id: DemoTitle.cpp,v 1.16 2010/02/01 08:28:12 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -157,7 +157,7 @@ void DemoTitle::init()
 
 	WSCstring sFontPoint = TITLE_FONT_POINT * 10;
 	WSCstring sFontName = "";
-	sFontName += "-*-*-*-i-normal--*-";
+	sFontName += "-*-*-*-i-normal-*-*-";
 	sFontName += sFontPoint;
 	sFontName += "-*,-*";
 
