@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2010 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GuiMessage.cpp,v 1.50 2009/07/03 10:36:42 bowkenken Exp $
+* $Id: GuiMessage.cpp,v 1.52 2010/02/01 08:28:12 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -150,7 +150,7 @@ void GuiMessage::newWin()
 		mStyle = gtk_style_copy( gtk_widget_get_default_style() );
 
 	GdkFont *font = gdk_fontset_load(
-			"-adobe-helvetica-medium-r-normal--*"
+			"-adobe-helvetica-medium-r-normal-*-*"
 			"-140-*,-*" );
 	gtk_style_set_font( mStyle, font );
 
