@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2010 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: PcgDunTab.h,v 1.30 2009/08/28 05:40:19 bowkenken Exp $
+* $Id: PcgDunTab.h,v 1.32 2010/01/07 07:22:37 bowkenken Exp $
 ***************************************************************/
 
 #ifndef PCG_DUN_TAB_H
@@ -1807,6 +1807,12 @@ PcgTab gPcgTabMnstr[] = {
 		"character/monster/devil/greater_daemon/",
 	},
 	/* ܥ */
+	{
+		MNSTR_KIND_HIGH_RE_HOO,
+		FACE_MJR_NULL, FACE_MNR_NULL,
+		100,
+		"character/monster/giant/high_re_hoo/",
+	},
 	{
 		MNSTR_KIND_GREAT_MINOTAUR,
 		FACE_MJR_NULL, FACE_MNR_NULL,
@@ -1814,10 +1820,22 @@ PcgTab gPcgTabMnstr[] = {
 		"character/monster/hybrid/great_minotaur/",
 	},
 	{
-		MNSTR_KIND_HIGH_RE_HOO,
+		MNSTR_KIND_BILLION_ELEMENTAL,
 		FACE_MJR_NULL, FACE_MNR_NULL,
 		100,
-		"character/monster/giant/high_re_hoo/",
+		"character/monster/elemental/billion_elemental/",
+	},
+	{
+		MNSTR_KIND_CYBERN,
+		FACE_MJR_NULL, FACE_MNR_NULL,
+		100,
+		"character/monster/magical/cybern/",
+	},
+	{
+		MNSTR_KIND_GIGANTIC_CENTIPEDE,
+		FACE_MJR_NULL, FACE_MNR_NULL,
+		100,
+		"character/monster/huge/gigantic_centipede/",
 	},
 	{
 		MNSTR_KIND_MEDUSA_ZOMBIE,
@@ -1838,10 +1856,16 @@ PcgTab gPcgTabMnstr[] = {
 		"character/monster/undead/vampire_lord/",
 	},
 	{
-		MNSTR_KIND_GIGANTIC_CENTIPEDE,
+		MNSTR_KIND_RELATIVISTIC_DAEMON,
 		FACE_MJR_NULL, FACE_MNR_NULL,
 		100,
-		"character/monster/huge/gigantic_centipede/",
+		"character/monster/devil/relativistic_daemon/",
+	},
+	{
+		MNSTR_KIND_ETERNAL_DRAGON,
+		FACE_MJR_NULL, FACE_MNR_NULL,
+		100,
+		"character/monster/dragon/eternal_dragon/",
 	},
 	/* 饹ܥ */
 	{
