@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: amenu-tab.h,v 1.21 2010/01/07 07:12:21 bowkenken Exp $
+* $Id: amenu-tab.h,v 1.22 2010/05/29 12:09:03 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	AMENU_TAB_H
@@ -34,8 +34,8 @@
 /* ưޡ˥塼 */
 
 static menu_t	ls_menu_auto_mark
-		[1 + 1 + (14 * AUTO_MARK_MAX_N)
-		+ (2 * AUTO_MARK_PAGE_N) + 2];
+		[1 + (14 * AUTO_MARK_MAX_N)
+		+ (3 * AUTO_MARK_PAGE_N) + 2];
 
 static menu_t	ls_menu_appoint_item
 		[1 + 1 + (AUTO_MARK_APPOINT_ITEM_MAX_N * 2) + 1];
