@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2010 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: mmenu-tab.h,v 1.47 2009/07/11 13:56:59 bowkenken Exp $
+* $Id: mmenu-tab.h,v 1.59 2010/05/13 17:31:58 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	MMENU_TAB_H
@@ -498,7 +498,7 @@ menu_t	ls_menu_main[] = {
 	{
 		"/misc/stairs/last boss",
 		"<Item>",
-		'D',
+		'X',
 		"",
 		N_MSG_MENU_STAIRS_LAST_BOSS, "",
 		cb_menu_stairs_last_boss, NULL,
@@ -558,6 +558,15 @@ menu_t	ls_menu_main[] = {
 		cb_menu_formation, NULL,
 		FLG_NULL,
 	},
+	{
+		"/misc/position",
+		"<Branch>",
+		'P',
+		"",
+		N_MSG_MENU_POSITION, "",
+		cb_menu_position, NULL,
+		FLG_NULL,
+	},
 	{
 		"/misc/cursor",
 		"<Branch>",
@@ -795,12 +804,39 @@ menu_t	ls_menu_main[] = {
 		FLG_NULL,
 	},
 	{
-		"/misc/config/screen/window/size/lines",
+		"/misc/config/screen/window/size/column",
 		"<OpenWinItem>",
-		'L',
+		'C',
 		"",
-		N_MSG_MENU_SCREEN_SIZE_LINES, "",
-		cb_menu_screen_size_lines, NULL,
+		N_MSG_MENU_SCREEN_SIZE_COL, "",
+		cb_menu_screen_size_col, NULL,
+		FLG_NULL,
+	},
+	{
+		"/misc/config/screen/window/size/row",
+		"<OpenWinItem>",
+		'R',
+		"",
+		N_MSG_MENU_SCREEN_SIZE_ROW, "",
+		cb_menu_screen_size_row, NULL,
+		FLG_NULL,
+	},
+	{
+		"/misc/config/screen/window/size/message",
+		"<OpenWinItem>",
+		'S',
+		"",
+		N_MSG_MENU_SCREEN_SIZE_MESSAGE, "",
+		cb_menu_screen_size_message, NULL,
+		FLG_NULL,
+	},
+	{
+		"/misc/config/screen/window/size/map",
+		"<CheckItem>",
+		'M',
+		"",
+		N_MSG_MENU_SCREEN_SIZE_MAP, "",
+		cb_menu_screen_size_map, NULL,
 		FLG_NULL,
 	},
 /* VFX begin */
@@ -931,6 +967,51 @@ menu_t	ls_menu_main[] = {
 		cb_menu_crsr_ptn, NULL,
 		FLG_NULL,
 	},
+	{
+		"/misc/config/screen/demo",
+		"<Branch>",
+		'D',
+		"",
+		N_MSG_MENU_DEMO, "",
+		cb_menu_demo, NULL,
+		FLG_NULL,
+	},
+	{
+		"/misc/config/screen/demo/cut in",
+		"<CheckItem>",
+		'C',
+		"",
+		N_MSG_MENU_SKIP_CUT_IN, "",
+		cb_menu_skip_cut_in, NULL,
+		FLG_NULL,
+	},
+	{
+		"/misc/config/screen/demo/star",
+		"<Branch>",
+		'S',
+		"",
+		N_MSG_MENU_STAR, "",
+		NULL, NULL,
+		FLG_NULL,
+	},
+	{
+		"/misc/config/screen/demo/star/cui",
+		"<OpenWinItem>",
+		'C',
+		"",
+		N_MSG_MENU_STAR_CUI, "",
+		cb_menu_star_cui, NULL,
+		FLG_NULL,
+	},
+	{
+		"/misc/config/screen/demo/star/gui",
+		"<OpenWinItem>",
+		'G',
+		"",
+		N_MSG_MENU_STAR_GUI, "",
+		cb_menu_star_gui, NULL,
+		FLG_NULL,
+	},
 /*  end */
 	{
 		"/misc/config/key",
@@ -1068,14 +1149,68 @@ menu_t	ls_menu_main[] = {
 		FLG_NULL,
 	},
 	{
-		"/misc/config/gui/replay music",
-		"<Item>",
+		"/misc/config/gui/audio",
+		"<Branch>",
+		'A',
+		"",
+		N_MSG_MENU_AUDIO, "",
+		cb_menu_audio, NULL,
+		FLG_NULL,
+	},
+	{
+		"/misc/config/gui/audio/sound volume",
+		"<OpenWinItem>",
+		'S',
+		"",
+		N_MSG_MENU_SOUND_VOLUME, "",
+		cb_menu_sound_volume, NULL,
+		FLG_NULL,
+	},
+	{
+		"/misc/config/gui/audio/music volume",
+		"<OpenWinItem>",
 		'M',
+		"",
+		N_MSG_MENU_MUSIC_VOLUME, "",
+		cb_menu_music_volume, NULL,
+		FLG_NULL,
+	},
+	{
+		"/misc/config/gui/audio/mute",
+		"<CheckItem>",
+		'U',
+		"",
+		N_MSG_MENU_MUTE_AUDIO, "",
+		cb_menu_mute_audio, NULL,
+		FLG_NULL,
+	},
+	{
+		"/misc/config/gui/audio/replay music",
+		"<Item>",
+		'R',
 		"p",
 		N_MSG_MENU_REPLAY_MUSIC, "",
 		cb_menu_replay_music, NULL,
 		FLG_NULL,
 	},
+	{
+		"/misc/config/gui/audio/set buffer size",
+		"<OpenWinItem>",
+		'B',
+		"",
+		N_MSG_MENU_SET_AUDIO_BUF_SIZ, "",
+		cb_menu_set_audio_buf_siz, NULL,
+		FLG_NULL,
+	},
+	{
+		"/misc/config/gui/mouse",
+		"<Branch>",
+		'M',
+		"",
+		N_MSG_MENU_MOUSE, "",
+		cb_menu_mouse, NULL,
+		FLG_NULL,
+	},
 	{
 		"/misc/config/gui/joystick",
 		"<Branch>",
@@ -1130,6 +1265,15 @@ menu_t	ls_menu_main[] = {
 		cb_menu_joystick_sel_kind, (void *)JOY_KIND_RAP3,
 		FLG_NULL,
 	},
+	{
+		"/misc/config/gui/joystick/macro",
+		"<Branch>",
+		'M',
+		"",
+		N_MSG_MENU_JOYSTICK_MACRO, "",
+		cb_menu_joystick_macro_init, NULL,
+		FLG_NULL,
+	},
 	{
 		"/misc/config/user menu select",
 		"<Branch>",
@@ -1945,6 +2089,7 @@ menu_t	ls_menu_mark_trap[] = {
 };
 
 menu_t	ls_menu_item[MBR_ITEM_MAX_N * 2 * MBR_MAX_N];
+menu_t	ls_menu_chest[1 + 1 + CHEST_HOLD_MAX_N + 1];
 
 menu_t	ls_menu_item_sel[] = {
 	{
@@ -2064,6 +2209,24 @@ menu_t	ls_menu_item_sel[] = {
 		cb_menu_item_receive, NULL,
 		FLG_NULL,
 	},
+	{
+		"/item sel/put in chest",
+		"<OpenWinItem>",
+		'U',
+		"",
+		N_MSG_MENU_ITEM_PUT_IN_CHEST, "",
+		cb_menu_item_put_in_chest, NULL,
+		FLG_NULL,
+	},
+	{
+		"/item sel/list chest",
+		"<OpenWinItem>",
+		'L',
+		"",
+		N_MSG_MENU_ITEM_LS_CHEST, "",
+		cb_menu_item_ls_chest, NULL,
+		FLG_NULL,
+	},
 	{
 		"/item sel/drop",
 		"<OpenWinItem>",
