@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2010 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: pet.c,v 1.67 2009/06/26 16:58:16 bowkenken Exp $
+* $Id: pet.c,v 1.72 2010/01/07 07:12:21 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -337,6 +337,25 @@ void	act_phase_all_pet( void )
 	}
 }
 
+/***************************************************************
+* ƤΥڥåȤԥե¹
+***************************************************************/
+
+void	dismissal_phase_all_pet( void )
+{
+	long	i;
+
+	for( i = 0; i < PET_MAX_N; i++ ){
+		pet_t	*pp;
+
+		pp = party_pet[i];
+		if( pp == NULL )
+			continue;
+
+		dismissal_phase_chr( pp );
+	}
+}
+
 /***************************************************************
 * ڥåȤɸŪʹư
 * pet_t *p : ڥå
@@ -464,6 +483,12 @@ pet_t	*get_pet( long x, long y )
 	pet_t	*p;
 	long	i;
 
+	if( !clip_pos( x, y ) )
+		return NULL;
+
+	if( dun->map.chr.mjr[y][x] == FACE_MJR_NULL )
+		return NULL;
+
 	p = dun->map.chr_p[y][x];
 	if( (p != NULL) && is_pet( p ) )
 		return p;
@@ -559,16 +584,17 @@ void	chk_pet_owner( pet_t *p )
 	if( p == NULL )
 		return;
 
-	if( p->owner == NULL )
-		clr_pet_owner( p );
-
-	if( (p->owner != NULL) && chk_flg_or( p->owner->stat,
-			FLG_STAT_NOT_EXIST | FLG_STAT_DEAD ) ){
+	if( p->owner == NULL ){
 		clr_pet_owner( p );
+	} else {
+		if( chk_flg_or( p->owner->stat,
+				FLG_STAT_NOT_EXIST | FLG_STAT_DEAD ) ){
+			clr_pet_owner( p );
+		}
+		if( p->owner->mbr_n == MBR_N_NOT_JOIN ){
+			clr_pet_owner( p );
+		}
 	}
-
-	if( (p->owner != NULL) && (p->owner->mbr_n == MBR_N_NOT_JOIN) )
-		clr_pet_owner( p );
 }
 
 /***************************************************************
@@ -752,6 +778,29 @@ bool_t	dismissal( pet_t *p )
 	return TRUE;
 }
 
+/***************************************************************
+* ѡƥΥڥåȤο
+* return : ڥåȤο
+***************************************************************/
+
+long	calc_pet_n( void )
+{
+	long	n;
+	long	i;
+
+	n = 0;
+	for( i = 0; i < PET_MAX_N; i++ ){
+		if( party_pet[i] == NULL )
+			continue;
+		if( chk_flg( party_pet[i]->stat, FLG_STAT_NOT_EXIST ) )
+			continue;
+
+		n++;
+	}
+
+	return n;
+}
+
 /***************************************************************
 * ꡼å
 ***************************************************************/
