@@ -39,7 +39,7 @@ void	party_enter_bar( void );
 void	party_exit_bar( void );
 bool_t	chk_shop_open( shop_n_t shop_n, bool_t flg_print );
 bool_t	chk_package_item( item_t *item );
-void	stay_inn( bool_t flg_short_stay, bool_t flg_mews );
+void	stay_inn( stay_inn_kind_t kind );
 void	take_bath( chr_t *chr );
 bool_t	set_art_name( mbr_t *mbr, item_t *art, deal_kind_t kind );
 bool_t	set_art_name_equip( mbr_t *mbr, item_t *art, equip_kind_t eq );
@@ -72,7 +72,7 @@ bool_t	chk_discount_open();
 bool_t	chk_discount_door( door_t *dr );
 bool_t	chk_queue_chr( chr_t *chr );
 bool_t	chk_discount_mark( chr_t *chr );
-void	set_discount();
+void	set_discount( void );
 void	clr_discount( void );
 void	set_discount_sold_out();
 bool_t	set_discount_queue( door_t *dr );
@@ -89,6 +89,7 @@ town_ptn_col_tab_t	*get_town_ptn_col_tab( void );
 long	get_town_ptn_col_tab_max_n( void );
 art_ls_pet_shop_t	*get_art_ls_pet_shop( void );
 bool_t	save_town( void );
+void	check_memory_town_c( void );
 
 #ifdef __cplusplus
 }
