@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2010 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: town.c,v 1.157 2009/07/11 03:42:14 bowkenken Exp $
+* $Id: town.c,v 1.161 2010/05/29 14:37:00 bowkenken Exp $
 ***************************************************************/
 
 #define	TOWN_C
@@ -38,6 +38,7 @@
 #define	TOWNER_AVE_N	64
 
 #define	FLOOR_IS_FIND_NIGHT	1
+#define	FLG_RESET_RESI_STAY_INN	0
 
 /***************************************************************
 * ŹαĶȻ
@@ -2024,18 +2025,20 @@ bool_t	chk_package_item( item_t *item )
 
 /***************************************************************
 * ɲ
-* bool_t flg_short_stay : ٷƤ?
-* bool_t flg_mews : Ͼ뤫?
 ***************************************************************/
 
-void	stay_inn( bool_t flg_short_stay, bool_t flg_mews )
+void	stay_inn( stay_inn_kind_t kind )
 {
+	bool_t flg_short_stay, flg_mews;
 	party_t	*pty = get_party();
 	pet_t	**pet = get_party_pet();
 	long	turn;
 	fx_t	*fx;
 	long	i, j;
 
+	flg_short_stay = (kind == STAY_INN_KIND_SHORT);
+	flg_mews = (kind == STAY_INN_KIND_MEWS);
+
 	if( flg_short_stay ){
 		turn = 12 * TURN_PER_HOUR;
 	} else {
@@ -2068,11 +2071,13 @@ void	stay_inn( bool_t flg_short_stay, bool_t flg_mews )
 		/* MP  */
 		mbr->abl.mp.n = mbr->abl.mp.max;
 
-		/* ͤꥻå */
-		for( j = 0; j < RESI_KIND_MAX_N; j++ ){
-			reset_mbr_resi( mbr );
-			mbr->resi[j].n = get_resi_max(
-					mbr, (resi_kind_t)j );
+		if( FLG_RESET_RESI_STAY_INN ){
+			/* ͤꥻå */
+			for( j = 0; j < RESI_KIND_MAX_N; j++ ){
+				reset_mbr_resi( mbr );
+				mbr->resi[j].n = get_resi_max(
+						mbr, (resi_kind_t)j );
+			}
 		}
 
 		/* 줤 */
@@ -2086,6 +2091,9 @@ void	stay_inn( bool_t flg_short_stay, bool_t flg_mews )
 
 		/* ̤ۤդ */
 		clean_all_disposal( mbr );
+
+		/* פ */
+		update_playing_report_staying_inn_mbr( mbr->ls_mbr_n, kind );
 	}
 
 	for( i = 0; i < PET_MAX_N; i++ ){
@@ -2121,6 +2129,9 @@ void	stay_inn( bool_t flg_short_stay, bool_t flg_mews )
 		take_meal_fill_chr( pet[i] );
 	}
 
+	/* פ */
+	update_playing_report_staying_inn_party( kind );
+
 	reset_turn( get_turn() + turn );
 	reset_all( FALSE );
 	reset_glow();
@@ -2844,7 +2855,7 @@ gold_t	get_price_temple_remove_curse( mbr_t *mbr )
 
 	price = PRICE_TEMPLE_REMOVE_CURSE;
 
-	price = discount( price, SHOP_N_INN, DEAL_KIND_BUY );
+	price = discount( price, SHOP_N_TEMPLE, DEAL_KIND_BUY );
 
 	return price;
 }
@@ -2873,7 +2884,7 @@ gold_t	get_price_temple_cure_status( mbr_t *mbr )
 
 	price += price * smoker / _100_PERCENT;
 
-	price = discount( price, SHOP_N_INN, DEAL_KIND_BUY );
+	price = discount( price, SHOP_N_TEMPLE, DEAL_KIND_BUY );
 
 	return price;
 }
@@ -2902,7 +2913,7 @@ gold_t	get_price_temple_resurrection( mbr_t *mbr )
 
 	price += price * smoker / _100_PERCENT;
 
-	price = discount( price, SHOP_N_INN, DEAL_KIND_BUY );
+	price = discount( price, SHOP_N_TEMPLE, DEAL_KIND_BUY );
 
 	return price;
 }
@@ -2923,7 +2934,7 @@ gold_t	get_price_temple_contribution( mbr_t *mbr )
 	if( price < PRICE_TEMPLE_CONTRIBUTION_PRICE_MIN )
 		price = PRICE_TEMPLE_CONTRIBUTION_PRICE_MIN;
 
-	price = discount( price, SHOP_N_INN, DEAL_KIND_BUY );
+	price = discount( price, SHOP_N_TEMPLE, DEAL_KIND_BUY );
 
 	return price;
 }
